@@ -4,3 +4,6 @@
 class DGSError(Exception):
     """Use to capture error DGS construction."""
 
+
+class TemplateStorageError(DGSError):
+    """Use to capture error for TemplateStorage."""
